@@ -2,5 +2,5 @@
 from ._version import version as __version__
 from .core import QPImage
 from . import holo
-from .meta import META_KEYS
+from .meta import META_KEYS, MetaDict
 from .series import QPSeries
